@@ -6,7 +6,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2015-2024 Univention GmbH
+# Copyright 2015-2025 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -129,9 +129,9 @@ def access(image):
         if exc.getcode() == 401:
             return False
         else:
-            return False  # TODO
+            return False  # TODO:
     except (urllib.error.URLError, ssl.CertificateError, http.client.BadStatusLine):
-        return False  # TODO
+        return False  # TODO:
     else:
         return True
 
@@ -345,8 +345,7 @@ class Docker:
     def path(self, filename=''):
         if self.container is None:
             return
-        if filename.startswith('/'):
-            filename = filename[1:]
+        filename = filename.removeprefix('/')
         return os.path.join(self.root_dir, filename)
 
     def ucr_filter_env_file(self, env):
