@@ -6,7 +6,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2015-2024 Univention GmbH
+# Copyright 2015-2025 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -126,9 +126,7 @@ class List(UniventionAppAction):
             return True
         if app.name.lower() in the_list:
             return True
-        if any(category.lower() in the_list for category in app.categories):
-            return True
-        return False
+        return bool(any(category.lower() in the_list for category in app.categories))
 
     def _list(self, pattern):
         ret = []
