@@ -6,7 +6,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2015-2024 Univention GmbH
+# Copyright 2015-2025 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -91,9 +91,7 @@ class Remove(InstallRemoveUpgrade):
         super()._run_parts(directory)
 
     def needs_credentials(self, app):
-        if os.path.exists(app.get_cache_file(self.prescript_ext)):
-            return True
-        return False
+        return bool(os.path.exists(app.get_cache_file(self.prescript_ext)))
 
     def _remove_app(self, app, args):
         self._configure(app, args)
