@@ -6,7 +6,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2015-2024 Univention GmbH
+# Copyright 2015-2025 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -108,9 +108,7 @@ class Upgrade(Install):
             return True
         if app.docker and app.docker_script_update_packages:
             return True
-        if app.docker and app.docker_script_update_app_version:
-            return True
-        return False
+        return bool(app.docker and app.docker_script_update_app_version)
 
     def _revert(self, app, args):
         try:
