@@ -6,7 +6,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2017-2024 Univention GmbH
+# Copyright 2017-2025 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -97,7 +97,7 @@ class IniSectionAttribute(UniventionMetaInfo):
         self.choices = choices
 
     def _canonical_name(self):
-        return re.sub('_', '', self.name)
+        return self.name.replace('_', '')
 
     @classmethod
     def _fetch_from_parser(cls, parser, section, name):
