@@ -2,7 +2,7 @@
  * Like what you see? Join us!
  * https://www.univention.com/about-us/careers/vacancies/
  *
- * Copyright 2020-2024 Univention GmbH
+ * Copyright 2020-2025 Univention GmbH
  *
  * https://www.univention.de/
  *
@@ -33,10 +33,11 @@
 
 define([
 	"dojo/_base/declare",
+	"dompurify/purify",
 	"umc/widgets/Text",
 	"./AppText",
 	"umc/i18n!umc/modules/appcenter"
-], function(declare, Text, AppText, _) {
+], function(declare, purify, Text, AppText, _) {
 	return {
 		getPageConf: function(app, readme) {
 			if (!app[readme]) {
@@ -55,14 +56,9 @@ define([
 					type: Text,
 					'class': 'appInstallDialog__readme',
 					name: `readmeInstall_readme_${app.id}`,
-					content: app[readme]
+					content: purify.sanitize(app[readme])
 				}]
 			};
 		}
 	};
 });
-
-
-
-
-
