@@ -2,7 +2,7 @@
  * Like what you see? Join us!
  * https://www.univention.com/about-us/careers/vacancies/
  *
- * Copyright 2017-2024 Univention GmbH
+ * Copyright 2017-2025 Univention GmbH
  *
  * https://www.univention.de/
  *
@@ -85,7 +85,7 @@ define([
 					lengthContent += _('After saving, the file will be deleted.');
 				}
 			}
-			this._content.set('content', _('File will be uploaded to %s.', '<em>' + this.fileName + '</em>') + ' ' + lengthContent);
+			this._content.set('content', _('File will be uploaded to %s.', '<em>' + entities.encode(this.fileName) + '</em>') + ' ' + lengthContent);
 		}
 	});
 });
