@@ -3,7 +3,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2020-2024 Univention GmbH
+# Copyright 2020-2025 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -37,7 +37,7 @@ import pytest
 ANYTHING = object()
 
 
-@pytest.fixture()
+@pytest.fixture
 def custom_apps_umc(custom_apps):
     custom_apps.load('unittests/inis/umc/')
     return custom_apps
